<?php
/**
 * playsports functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package playsports
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.15' );
}

if ( ! function_exists( 'playsports_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function playsports_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on playsports, use a find and replace
		 * to change 'playsports' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'playsports', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'playsports' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'playsports_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */


		add_theme_support(
			'custom-logo',
			array(
				'height'      => 52,
				'width'       => 200,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'playsports_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function playsports_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'playsports_content_width', 640 );
}
add_action( 'after_setup_theme', 'playsports_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function playsports_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'playsports' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'playsports' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'playsports_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function playsports_scripts() {
	wp_enqueue_style( 'playsports-bootstrap', get_template_directory_uri() . '/vendor/bootstrap/css/bootstrap.min.css', array(), _S_VERSION );
	// wp_enqueue_style( 'playsports-fontawesome', get_template_directory_uri() . '/vendor/fontawesome/css/all.min.css', array(), _S_VERSION );
	wp_enqueue_style( 'playsports-slick', get_template_directory_uri() . '/vendor/slick/slick.css', array(), _S_VERSION);
	wp_enqueue_style( 'playsports-slick-theme', get_template_directory_uri() . '/vendor/slick/slick-theme.css', array(), _S_VERSION );
	wp_enqueue_style( 'playsports-owl-carousel', get_template_directory_uri() . '/vendor/owl-carousel/assets/owl.carousel.min.css', array(), _S_VERSION );

	wp_enqueue_style( 'playsports-animate', 'https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css', array(), _S_VERSION );

	wp_enqueue_style( 'playsports-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'playsports-style', 'rtl', 'replace' );

	wp_enqueue_script( 'playsports-modernizr', get_template_directory_uri() . '/js/modernizr.js', array(), _S_VERSION, false );

	wp_enqueue_script( 'playsports-jquery', get_template_directory_uri() . '/js/jquery-3.3.1.min.js', array(), _S_VERSION, false );

	wp_enqueue_script( 'playsports-popper', get_template_directory_uri() . '/js/popper.min.js', array(), _S_VERSION, false );

	wp_enqueue_script( 'playsports-bootstrap', get_template_directory_uri() . '/vendor/bootstrap/js/bootstrap.bundle.min.js', array(), _S_VERSION, false );

// 	wp_enqueue_script( 'playsports-slick', get_template_directory_uri() . '/vendor/slick/slick.min.js', array(), _S_VERSION, true );

// 	wp_enqueue_script( 'playsports-owl-carousel', get_template_directory_uri() . '/vendor/owl-carousel/owl.carousel.min.js', array(), _S_VERSION, true );

// 	wp_enqueue_script( 'playsports-easy-ticker', get_template_directory_uri() . '/js/jquery.easy-ticker.js', array(), _S_VERSION, false );

	wp_enqueue_script( 'playsports-countdown', get_template_directory_uri() . '/js/countdown.js', array(), 1, true );
	wp_enqueue_script( 'playsports-bbif', get_template_directory_uri() . '/js/bbif.js', array(), 1.1, true );
	// wp_enqueue_script( 'playsports-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'playsports_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
